/**
 * Custom React hook for fetching data asynchronously.
 * @param {Function} fetchData - A function that returns a promise which resolves to the fetched data.
 * @returns An object containing the fetched data, loading state, and error state.
 * @template T - The type of data being fetched.
 */
export declare function useFetch<T>(fetchData: () => Promise<T>): {
    data: T | undefined;
    loading: boolean;
    error: unknown;
};
