import type { HeatMapDetail, MatchedUser, RecentSubmission, SubmitStats, UserContestInfo } from '../types';
/**
 * Represents a class for querying user data from LeetCode.
 */
export declare class LeetcodeQuery {
    /**
     * Fetches data from the LeetCode Graphql endpoint.
     * @param {string} query - The GraphQL query string.
     * @param {string} username - The username for which to fetch the data.
     * @returns A promise resolving to the fetched data.
     * @private
     */
    private fetchData;
    /**
     * Fetches the user profile data.
     * @param {string} userName - The username of the user.
     * @returns {Promise<MatchedUser>} A promise resolving to the user profile data.
     */
    fetchUserProfile(userName: string): Promise<MatchedUser>;
    /**
     * Fetches details of the user's contest participation.
     * @param {string} userName - The username of the user.
     * @returns {Promise<UserContestInfo>} A promise resolving to the user's contest details.
     */
    fetchUserContestDetails(userName: string): Promise<UserContestInfo>;
    /**
     * Fetches statistics of the user's solved problems.
     * @param {string} userName - The username of the user.
     * @returns {Promise<SubmitStats>} A promise resolving to the user's solved problems statistics.
     */
    fetchUserSolvedProblemsStats(userName: string): Promise<SubmitStats>;
    /**
     * Fetches the user's recent submissions.
     * @param {string} userName - The username of the user.
     * @returns {Promise<RecentSubmission[]>} A promise resolving to an array of recent submissions.
     */
    fetchUserRecentSubmissions(userName: string): Promise<RecentSubmission[]>;
    /**
     * Fetches the user's heatmap data.
     * @param {string} userName - The username of the user.
     * @returns {Promise<HeatMapDetail[]>} A promise resolving to an array of heatmap details.
     */
    fetchUserHeatMap(userName: string): Promise<HeatMapDetail[]>;
}
declare const _default: LeetcodeQuery;
export default _default;
